# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AuthUser(Component):
    """An AuthUser component.
Get authenticated user
State
- client (dictionary): Client information
- authUser (dictionary): Authenticated user information
- token (string): Access Token

Keyword arguments:

- id (string; default 'po-auth'):
    Unique ID to identify this component in Dash callbacks.

- apiKey (string; optional):
    API key from Pollination Cloud.

- basePath (string; default 'https://api.pollination.cloud'):
    Base path of the API."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'pollination_dash_io'
    _type = 'AuthUser'
    @_explicitize_args
    def __init__(self, apiKey=Component.UNDEFINED, basePath=Component.UNDEFINED, id=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'apiKey', 'basePath']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'apiKey', 'basePath']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AuthUser, self).__init__(**args)



from typing import List

from dash import Dash, Input, Output
from dash.development.base_component import Component
from .GetAPIKey import GetAPIKey

class ApiKey:
    def __init__(self, id: str = 'po-api-key'):
        self.id = id

    @property
    def component(self):
        return GetAPIKey(id=self.id)
    
    def create_api_key_callback(self, app: Dash, component_ids: List[str]):
        input = Input(component_id='po-api-key', component_property='apiKey')
        outputs = [Output(component_id=component_id, component_property='apiKey') for component_id in component_ids]

        def callback(apiKey):
            return [apiKey for _ in range(len(outputs))]
        
        app.callback(outputs, input)(callback)

    def inject_components(self, app: Dash, components: List[Component]):
        self.create_api_key_callback(app=app, component_ids=[c.id for c in components])